@@ -11,13 +11,13 @@
 #define VERSION_EXTRA ""
 
 /* Version number of Wireshark and associated utilities */
-#define VERSION "4.6.0"
+#define VERSION "4.6.2"
 #define VERSION_MAJOR 4
 #define VERSION_MINOR 6
-#define VERSION_MICRO 0
+#define VERSION_MICRO 2
 
 /* Version number of Stratoshark and associated utilities */
-#define STRATOSHARK_VERSION "0.9.3rc0-972-gcdfb6721e77c"
+#define STRATOSHARK_VERSION "0.9.3rc0-1098-g24d5e2b5a3dc"
 
 #define PLUGIN_PATH_ID "4.6"
 #define VERSION_FLAVOR ""
@@ -128,7 +128,7 @@
 #define HAVE_LIBGNUTLS 1
 
 /* Define to 1 if GnuTLS was built with pkcs11 support. */
-#define HAVE_GNUTLS_PKCS11 1
+/* #undef HAVE_GNUTLS_PKCS11 */
 
 /* Enable libnl support */
 #define HAVE_LIBNL 1
@@ -146,8 +146,8 @@
 /* #undef HAVE_SMI_VERSION_STRING */
 
 /* Define to use xxhash library */
-#define HAVE_XXHASH 1
-#define XXHASH_VERSION_STRING "0.8.3"
+/* #undef HAVE_XXHASH */
+#define XXHASH_VERSION_STRING ""
 
 /* Define to use zlib library */
 #define HAVE_ZLIB 1
@@ -372,7 +372,7 @@
  * - The VersionNT parts of packaging\wix\Prerequisites.wxi
  */
 #  ifndef NTDDI_VERSION
-#  define NTDDI_VERSION   NTDDI_WIN10
+#  define NTDDI_VERSION   NTDDI_WIN10_RS5
 #  endif
 
 #  ifndef _WIN32_WINNT
